@@ -6,6 +6,9 @@ from pathlib import Path
 
 import click
 from gdrive_pydantic_wrapper.google_drive.gdrive import GDrive
+from rich.live import Live
+from rich.spinner import Spinner
+from rich.text import Text
 
 from environment_backups import CONFIGURATION_MANAGER
 from environment_backups.backups.backups import backup_environment, backup_envs
@@ -27,7 +30,7 @@ def async_cmd(func):
 @click.option('projects_folder', '-p', '--projects-folder', type=click.Path(exists=True), required=False)
 @click.option('backup_folder', '-b', '--backup-folder', type=click.Path(exists=False), required=False)
 @click.option('use_async', '--async', is_flag=True, default=False)
-async def backup(environment: str, projects_folder: Path, backup_folder: Path, use_async: bool ):
+async def backup(environment: str, projects_folder: Path, backup_folder: Path, use_async: bool):
     if environment:
         start = time.time()
         app_cfg = CONFIGURATION_MANAGER.get_current()
@@ -45,10 +48,13 @@ async def backup(environment: str, projects_folder: Path, backup_folder: Path, u
         click.secho(f'Saved {len(zip_list)} zip environments to {b_folder}. Took {elapsed:.2f} seconds.', fg='green')
 
         if env_cfg.get('google_drive_folder_id'):
-            secrets_file = Path(env_cfg.get('google_authentication_file'))
-            gdrive = GDrive(secrets_file=secrets_file)
-            gdrive.upload_folder(b_folder, env_cfg['google_drive_folder_id'])
-            click.secho(f'Uploaded {b_folder} to google drive')
+            # TODO add elapsed to upload
+            spinner = Spinner('dots3', text=Text('Uploading to Google Drive'))
+            with Live(spinner):
+                secrets_file = Path(env_cfg.get('google_authentication_file'))
+                gdrive = GDrive(secrets_file=secrets_file)
+                gdrive.upload_folder(b_folder, env_cfg['google_drive_folder_id'])
+            click.secho(f'Uploaded {b_folder} to google drive', fg='green')
     else:
         legacy_backup(backup_folder, projects_folder)
 
@@ -69,5 +75,5 @@ def legacy_backup(backup_folder, projects_folder):
     for i, zip_file in enumerate(zip_list, 1):
         click.secho(f'{i:3}. {zip_file.name}', fg='green')
 
+
 # TODO add backup by name. environment-backups backup --name adelantos --upload
-# TODO Upload to google after excectuting a backup.
